//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Data/DatafilePresenter.cpp
//! @brief     Implements class DatafilePresenter.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Data/DatafilePresenter.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/View/Frame/MaskEditingFrame.h"
#include "GUI/View/Frame/Plot2DFrame.h"
#include "GUI/View/Frame/Plot2DWithProjectionFrame.h"
#include "GUI/View/Frame/SpecularFrame.h"

DatafilePresenter::DatafilePresenter()
{
    registerWidget("Heat Map", [] { return new Plot2DFrame; });
    registerWidget("Projections", [] { return new Plot2DWithProjectionFrame; });
    registerWidget("Mask Editor", [] { return new MaskEditingFrame; });
    registerWidget("Reflectometry (Graph only)", [] { return new SpecularFrame; });
}

QString DatafilePresenter::itemPresentation() const
{
    if (!realItem())
        return selectedPresentation();

    if (realItem()->presentationType().isEmpty())
        return defaultPresentation();

    return realItem()->presentationType();
}

void DatafilePresenter::setThePresentation(const QString& presentationType)
{
    setComboPresentation(presentationType);
    if (realItem() && !presentationType.isEmpty())
        realItem()->setPresentationType(presentationType);
}

QStringList DatafilePresenter::activePresentationList() const
{
    ASSERT(realItem());

    QStringList result;
    if (realItem()->rank() == 2)
        result << "Heat Map"
               << "Projections"
               << "Mask Editor";
    else if (realItem()->rank() == 1) {
        result << "Reflectometry (Graph only)";
    } else
        ASSERT_NEVER;
    return result;
}
