//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Data/DatafilesStack.cpp
//! @brief     Implements class DatafilesStack.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Data/DatafilesStack.h"
#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/View/Data/DatafilePresenter.h"

void DatafilesStack::setItem(DatafileItem* item)
{
    if (!item) {
        hideWidgets();
        return;
    }

    DatafilePresenter* widget = itemWidget(item);

    if (!widget) {
        widget = new DatafilePresenter();
        m_stackedWidget->addWidget(widget);
        m_itemToWidget[item] = widget;
    }

    m_stackedWidget->setCurrentWidget(widget);
    if (widget->isHidden())
        widget->show();

    widget->setTheItem(item);
}

DatafilePresenter* DatafilesStack::itemWidget(DatafileItem* /*item*/)
{
    if (!m_itemToWidget.empty())
        return m_itemToWidget.first();
    return nullptr;
}
