//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Frame/Plot2DWithProjectionFrame.h
//! @brief     Defines class Plot2DWithProjectionFrame.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_FRAME_PLOT2DWITHPROJECTIONFRAME_H
#define BORNAGAIN_GUI_VIEW_FRAME_PLOT2DWITHPROJECTIONFRAME_H

#include "GUI/View/Access/DataAccessWidget.h"

class ProjectionActions;
class ProjectionsEditorCanvas;
class ProjectionsToolpanel;
class ProjectionsWidget;
class Scale2DEditor;

//! Main widget to embed projections editor for Data2DItem.
//! Part of DatafilePresenter and JobResultsPresenter.

class Plot2DWithProjectionFrame : public DataAccessWidget {
public:
    Plot2DWithProjectionFrame(QWidget* parent = nullptr);

    void setJobOrDatafileItem(QObject* item) override;

    QList<QAction*> actionList() override;

private:
    void updateProjsFrame();
    void showEvent(QShowEvent*) override;
    void hideEvent(QHideEvent*) override;
    void setup_connections();

    ProjectionActions* m_editorActions;
    ProjectionsToolpanel* m_toolbar;              //! main tool bar with buttons at the right
    ProjectionsEditorCanvas* m_projectionsCanvas; //! canvas with color map at the top
    ProjectionsWidget* m_projectionsWidget;       //! bottom widget to draw projections plot
    Scale2DEditor* m_scaleEditor;                 //! panel at the right with properties
};

#endif // BORNAGAIN_GUI_VIEW_FRAME_PLOT2DWITHPROJECTIONFRAME_H
